
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {

        Asset( "ANIM", "anim/player_basic.zip" ),
        Asset( "ANIM", "anim/player_idles_shiver.zip" ),
        Asset( "ANIM", "anim/player_actions.zip" ),
        Asset( "ANIM", "anim/player_actions_axe.zip" ),
        Asset( "ANIM", "anim/player_actions_pickaxe.zip" ),
        Asset( "ANIM", "anim/player_actions_shovel.zip" ),
        Asset( "ANIM", "anim/player_actions_blowdart.zip" ),
        Asset( "ANIM", "anim/player_actions_eat.zip" ),
        Asset( "ANIM", "anim/player_actions_item.zip" ),
        Asset( "ANIM", "anim/player_actions_uniqueitem.zip" ),
        Asset( "ANIM", "anim/player_actions_bugnet.zip" ),
        Asset( "ANIM", "anim/player_actions_fishing.zip" ),
        Asset( "ANIM", "anim/player_actions_boomerang.zip" ),
        Asset( "ANIM", "anim/player_bush_hat.zip" ),
        Asset( "ANIM", "anim/player_attacks.zip" ),
        Asset( "ANIM", "anim/player_idles.zip" ),
        Asset( "ANIM", "anim/player_rebirth.zip" ),
        Asset( "ANIM", "anim/player_jump.zip" ),
        Asset( "ANIM", "anim/player_amulet_resurrect.zip" ),
        Asset( "ANIM", "anim/player_teleport.zip" ),
        Asset( "ANIM", "anim/wilson_fx.zip" ),
        Asset( "ANIM", "anim/player_one_man_band.zip" ),
        Asset( "ANIM", "anim/shadow_hands.zip" ),
        Asset( "SOUND", "sound/sfx.fsb" ),
		Asset( "ANIM", "anim/wakes.zip" ),
		Asset( "ANIM", "anim/wakes_short.zip" ),
		Asset( "ANIM", "anim/wakes_med.zip" ),
		Asset( "ANIM", "anim/wakes_long.zip" ),
		Asset( "ANIM", "anim/wakes_hood.zip" ),
		Asset( "ANIM", "anim/wakes_hood_short.zip"),
		Asset( "ANIM", "anim/wakes_hood_med.zip"),
		Asset( "ANIM", "anim/wakes_hood_long.zip"),
		
}
local prefabs = {
"wakes_feather",
"wakes_spear",
"wakes_helmet",
"wakes_armor",
"wakes_backpack",
"wakes_eggs"
}

local fn = function(inst)

	---choose which sounds this character will play
	inst.soundsname = "wakes"

	---Minimap icon
	inst.MiniMapEntity:SetIcon( "wakes.tex" )
	inst:AddTag("IsNotHooded")
	inst:AddTag("NoFeathers")
	inst:AddTag("ShortFeathers")
	inst:AddTag("MedFeathers")
	inst:AddTag("LongFeathers")
	inst:RemoveTag("ShortFeathers")
	inst:RemoveTag("MedFeathers")
	inst:RemoveTag("LongFeathers")
	
	---Recipe Stuff
	
	local wakes_feather_small = Ingredient( "wakes_feather", 3)
	wakes_feather_small.atlas = "images/inventoryimages/wakes_feather.xml"
	
	local wakes_feather_med = Ingredient( "wakes_feather", 5)
	wakes_feather_med.atlas = "images/inventoryimages/wakes_feather.xml"
	
	local wakes_feather_large = Ingredient( "wakes_feather", 9)
	wakes_feather_large.atlas = "images/inventoryimages/wakes_feather.xml"
	
	---Her Spear recipe
	local wakes_spear_recipe = Recipe("wakes_spear", { Ingredient("twigs", 2),  Ingredient("rope",1), Ingredient("flint",1), wakes_feather_small }, RECIPETABS.WAR, {SCIENCE=1})
    wakes_spear_recipe.atlas = "images/inventoryimages/wakes_spear.xml"
	
	---Her Helmet recipe
	local wakes_helmet_recipe = Recipe("wakes_helmet", { Ingredient("pigskin", 1),  Ingredient("rope",1), Ingredient("flint",2), wakes_feather_med }, RECIPETABS.WAR, {SCIENCE=2})
    wakes_helmet_recipe.atlas = "images/inventoryimages/wakes_helmet.xml"
	
	---Her Armour recipe
	local wakes_armor_recipe = Recipe("wakes_armor", { Ingredient("log", 6),  Ingredient("rope",2), Ingredient("flint",2), Ingredient("goldnugget",2), wakes_feather_med }, RECIPETABS.WAR, {SCIENCE=1})
    wakes_armor_recipe.atlas = "images/inventoryimages/wakes_armor.xml"
	
	---Her Backpack recipe
	local wakes_backpack_recipe = Recipe("wakes_backpack", { Ingredient("cutgrass", 12),  Ingredient("silk",6), Ingredient("flint",2), Ingredient("goldnugget",2), wakes_feather_large }, RECIPETABS.SURVIVAL, {SCIENCE=1})
    wakes_backpack_recipe.atlas = "images/inventoryimages/wakes_backpack.xml"
	
	---Stats	
	inst.components.health:SetMaxHealth(130)
	inst.components.hunger:SetMax(135)
	inst.components.sanity:SetMax(175)
	inst.components.temperature.mintemp = (-35)
	inst.components.sanity.night_drain_mult = 0.85
	inst.components.temperature.inherentinsulation = (0)
	inst.components.health:SetAbsorptionAmount(0)
	if  IsDLCEnabled(CAPY_DLC) or IsDLCEnabled(PORKLAND_DLC) then
		inst.components.combat:AddDamageModifier("wakes", -0.25)
	else
		inst.components.combat.damagemultiplier = 0.75
	end
	
	---Damage multiplier
    inst.components.combat.damagemultiplier = 0.85
	
	---Hunger rate
	inst.components.hunger.hungerrate = 1 * TUNING.WILSON_HUNGER_RATE
	
	---Movement speed (optional)
	inst.components.locomotor.walkspeed = 4
	inst.components.locomotor.runspeed = 6
	
	---Poison Immunity
	inst:RemoveTag("poisonable")
	inst.components.health.vulnerabletopoisondamage = false
	inst.components.health.poison_damage_scale = 0

	
	---Feather-growing Stuff
	inst:AddComponent("beard")	
    local beard_days = {0, 4, 8, 12}
    local beard_bits = {3, 5, 8}
	local delta = 0
	local beard_stage = 0
	inst.components.beard.prize = "wakes_feather"
	
	
	
	---Hood Wearing Stuff
		if not inst:HasTag("playerghost") then
		inst:AddComponent("beard")
	end
    local beard_days = {0, 4, 8, 12}
    local beard_bits = {6, 10, 16}
	local delta = 0
	local beard_stage = 0
	inst.components.beard.prize = "wakes_feather"
	
	---Hood Wearing Stuff

    inst.components.beard:AddCallback(beard_days[1], function()
			inst:AddTag("NoFeathers")
			inst:RemoveTag("ShortFeathers")
			inst:RemoveTag("MedFeathers")
			inst:RemoveTag("LongFeathers")
			beard_stage = 0
			inst.components.sanity.dapperness = 0
			inst.components.beard.bits = 0
			if inst:HasTag("IsNotHooded") then
				inst.AnimState:SetBuild("wakes")
			else
				inst.AnimState:SetBuild("wakes_hood")
			end
    end)	

    inst.components.beard:AddCallback(beard_days[2], function()
			inst:AddTag("ShortFeathers")
			inst:RemoveTag("NoFeathers")
			beard_stage = 1
			inst.components.sanity.dapperness = -TUNING.DAPPERNESS_SMALL
			inst.components.beard.bits = beard_bits[1]
			if inst:HasTag("IsNotHooded") then
				inst.AnimState:SetBuild("wakes_short")
			else
				inst.AnimState:SetBuild("wakes_hood_short")
			end
    end)
    
    inst.components.beard:AddCallback(beard_days[3], function()
			inst:AddTag("MedFeathers")
			inst:RemoveTag("ShortFeathers")
			beard_stage = 2
			inst.components.sanity.dapperness = -TUNING.DAPPERNESS_MED
			inst.components.beard.bits = beard_bits[2]
			if inst:HasTag("IsNotHooded") then
				inst.AnimState:SetBuild("wakes_med")
			else
				inst.AnimState:SetBuild("wakes_hood_med")
			end
    end)
    
    inst.components.beard:AddCallback(beard_days[4], function()
			inst:AddTag("LongFeathers")
			inst:RemoveTag("MedFeathers")
			beard_stage = 3
			inst.components.sanity.dapperness = -TUNING.DAPPERNESS_LARGE
			inst.components.beard.bits = beard_bits[3]
			if inst:HasTag("IsNotHooded") then
				inst.AnimState:SetBuild("wakes_long")
			else
				inst.AnimState:SetBuild("wakes_hood_long")
			end
    end)
	
	---Can't wear hats when the hood is up!
	local _Equip = inst.components.inventory.Equip
	inst.components.inventory.Equip = function(self, item, old_to_active)
	if not item or not item.components.equippable or not item:IsValid() then
	return
	end
	if item.components.equippable.equipslot == EQUIPSLOTS.HEAD then
	if not inst:HasTag("IsNotHooded") then
	inst.components.talker:Say("My beautiful hood is in the way!")
	self:DropItem(item)
	self:GiveItem(item)
	return
	end
	end
	return _Equip(self, item, old_to_active)
	end
		
	---She likes eating bugs

	local function FoodAdjust(inst, food)
	if (food.components.edible.foodtype == "INSECT") then
		food.components.edible.hungervalue = (food.components.edible.hungervalue * 1.5)
	end
	end

	---She's cool with Being wet
	
	TUNING.WET_ITEM_DAPPERNESS = 0
	TUNING.WET_EMPTY_SLOT_DAPPERNESS = 0
	TUNING.MOISTURE_SANITY_PENALTY_MAX = 0
	
	---Her metabolism slows when it's cold(0.5)
	    local function CheckTemperature(inst)
        if inst.components.temperature then
            local t = inst.components.temperature
            if t:GetCurrent() > 15 and not inst:HasTag("tempy") then
                inst:AddTag("tempy")
                inst:RemoveTag("tempx")
                inst.components.hunger.burnrate = 1
            end
            if t:GetCurrent() < 15 and not inst:HasTag("tempx") then
                inst:AddTag("tempx")
                inst:RemoveTag("tempy")
                inst.components.hunger.burnrate = 0.5
            end
        end
    end
    inst:DoPeriodicTask( 0.0, function(inst)
        CheckTemperature(inst)
    end)
	---So she doesn't like being cold(-2.5)
	    local function CheckTemperature(inst)
        if inst.components.temperature then
            local t = inst.components.temperature
            if t:GetCurrent() > 5 and not inst:HasTag("tempy") then
                inst:AddTag("tempy")
                inst:RemoveTag("tempx")
                inst.components.sanity.dapperness = 0
            end
            if t:GetCurrent() < 5 and not inst:HasTag("tempx") then
                inst:AddTag("tempx")
                inst:RemoveTag("tempy")
                inst.components.sanity.dapperness = -2.5
            end
        end
    end
    inst:DoPeriodicTask( 0.0, function(inst)
        CheckTemperature(inst)
    end)

	---She's 25% weaker in the day
	
    inst:AddTag("off")
    local function CheckDay(inst)
        if GetClock() and GetWorld() then
            if not GetClock():IsDay() and inst:HasTag("on") and not GetWorld():IsCave() then
                inst:AddTag("off")
                inst:RemoveTag("on")
            end
            if GetClock():IsDay() and inst:HasTag("off") and not GetWorld():IsCave() then
                                if IsDLCEnabled(CAPY_DLC) or IsDLCEnabled(PORKLAND_DLC) then
					inst.components.combat:AddDamageModifier("wakes", -0.25)
				else
					inst.components.combat.damagemultiplier = 0.75
				end
                inst:AddTag("on")
                inst:RemoveTag("off")
            end
        end
    end
    inst:DoPeriodicTask( 0.0, function(inst) 
        CheckDay(inst)
     end)
	  
	---Dusk is the about average
		
	inst:AddTag("off")
    local function CheckDay(inst)
        if GetClock() and GetWorld() then
            if not GetClock():IsDusk() and inst:HasTag("on") and not GetWorld():IsCave() then
                inst:AddTag("off")
                inst:RemoveTag("on")
            end
            if GetClock():IsDusk() and inst:HasTag("off") and not GetWorld():IsCave() then
				if IsDLCEnabled(CAPY_DLC) or IsDLCEnabled(PORKLAND_DLC) then
					inst.components.combat:AddDamageModifier("wakes", 0)
				else
					inst.components.combat.damagemultiplier = 1
				end
                inst:AddTag("on")
                inst:RemoveTag("off")
            end
        end
    end
    inst:DoPeriodicTask( 0.0, function(inst) 
        CheckDay(inst)
    end)  
	  
	---The night gives a +25% damage bonus
		
	inst:AddTag("off")
    local function CheckDay(inst)
        if GetClock() and GetWorld() then
            if not GetClock():IsNight() and inst:HasTag("on") and not GetWorld():IsCave() then
                inst:AddTag("off")
                inst:RemoveTag("on")
            end
            if GetClock():IsNight() and inst:HasTag("off") and not GetWorld():IsCave() then
				if IsDLCEnabled(CAPY_DLC) or IsDLCEnabled(PORKLAND_DLC) then
					inst.components.combat:AddDamageModifier("wakes", 0.25)
				else
					inst.components.combat.damagemultiplier = 1.25
				end
                inst:AddTag("on")
                inst:RemoveTag("off")
            end
        end
    end
    inst:DoPeriodicTask( 0.0, function(inst) 
        CheckDay(inst)
    end)
	  
	---Reptiles tend to slow their movements when it's very cold (20%)
	  local function CheckTemperature(inst)
        if inst.components.temperature then
            local t = inst.components.temperature
            if t:GetCurrent() > 5 and not inst:HasTag("tempy") then
                inst:AddTag("tempy")
                inst:RemoveTag("tempx")
                inst.components.locomotor.walkspeed = 4
				inst.components.locomotor.runspeed = 6
            end
            if t:GetCurrent() < 5 and not inst:HasTag("tempx") then
                inst:AddTag("tempx")
                inst:RemoveTag("tempy")
                inst.components.locomotor.walkspeed = 3.2
				inst.components.locomotor.runspeed = 4.8
            end
        end
    end
    inst:DoPeriodicTask( 0.0, function(inst)
        CheckTemperature(inst)
    end)
	
	---She can't regulate her body temperature as well in Winter.(Max temp =45)
	    inst:ListenForEvent("seasonChange", function(it, data)
        if data.season == SEASONS.WINTER then
              inst.components.temperature.maxtemp = (45)
			  inst.components.hunger.burnrate = 0.85
			  inst.components.temperature.hurtrate = 1.15
        end
        if data.season == SEASONS.SPRING then
              inst.components.temperature.maxtemp = (95)
			  inst.components.hunger.burnrate = 1
			  inst.components.temperature.hurtrate = 1.15
        end
        if data.season == SEASONS.AUTUMN then
			inst.components.temperature.maxtemp = (95)
			inst.components.hunger.burnrate = 1
			inst.components.temperature.hurtrate = 1
        end
        if data.season == SEASONS.SUMMER then
			inst.components.temperature.maxtemp = (95)
			inst.components.hunger.burnrate = 1
			inst.components.temperature.hurtrate = 1
        end
    end, GetWorld())
    inst:PushEvent("seasonChange")

end




return MakePlayerCharacter("wakes", prefabs, assets, fn)

